#!/usr/bin/env perl

#
# Test file to prove line ending bug
# Unix version
# Unix has only \x0A as line ending

#
# Because strange Getopt::Euclid Magic:
# only one test per file / one test file per line ending type
#



use strict;
use warnings;

use Test::More tests => 1;

use File::Temp qw(tempdir);



#
# Initialise 
#


my $dir = tempdir( CLEANUP => 1 );


# diag "Tempdir: '$dir'\n"; 


#
# Write two modules
# one with unix and one with windows line endings
#
 
open my $unixfile, ">:raw", "$dir/TestUnix.pm" or die "Can't write Module: $!";


# get the contents from  my DATA section
while (<DATA>) {
   
    # remove all possible line endings ...
    s{[\x0A|\x0D]}{}g;
    
    # write this line with unix line endings: 0x0A
    s{--test}{--test-unix}msxg;
    s{(# Package name generated by testscript)}{package TestUnix; # $1}msg;
    print $unixfile "$_\x0A";
    
}

close $unixfile;



# Set the test command line parameters
@ARGV = ( "--test dummy", "--test-unix=mytest-unix", );

# use the generated modules
eval "use lib qw($dir)" ;
eval "use TestUnix;";
die "Can't use my Test Module: $@" if $@;


# ... and finally do the check!
is $ARGV{"--test-unix"} => "mytest-unix", "can read options from a file with unix line endings";



#
# Data for the dummy module follows
#

__DATA__

# Package name generated by testscript



use Getopt::Euclid;



1;

__END__


=head1 NAME

line-delimeter-test.pl - this is only POD for testing line delimeters

=head1 VERSION

This documentation refers to line-delimeter-test.pl version 1.2.3

=head1 USAGE

    line-delimeter-test.pl  --test something <other>

=head1 REQUIRED ARGUMENTS

=over

=item  --test [=] <something>    

Specify something

=back

=head1 OPTIONS

=over

=item <other>

=for Euclid:
    repeatable


=item --verbose

Print all warnings

=item --version

=item --usage

=item --help

=item --man

Print the usual program information

=back

=begin remainder of documentation here...

=end

=head1 AUTHOR

Alvar Freude

=head1 BUGS

Hopefully I'll find them ...

=cut


